==> haskell-hspec-wai-json-0.9.2-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.2
id: hspec-wai-json-0.9.2-Idv3dVMJ1rI4gvIDSX0pLt
key: hspec-wai-json-0.9.2-Idv3dVMJ1rI4gvIDSX0pLt
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2018 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
abi: 1e35614fe8307cc82487993e8b46a50f
exposed: True
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
import-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-wai-json-0.9.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-wai-json-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hspec-wai-json-0.9.2
hs-libraries: HShspec-wai-json-0.9.2-Idv3dVMJ1rI4gvIDSX0pLt
depends:
    aeson-1.4.2.0-3p7goNB3q4s1JbMrIJBuLL
    aeson-qq-0.8.2-84LJIsHmLQq1CrSgfDecTr base-4.12.0.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hspec-wai-0.9.2-9pDspXC7XxYAkbh9vdcUuk template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.9.2-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.2
id: hspec-wai-json-0.9.2-BZNRBMFwE4jKXoJhm8EnCY
key: hspec-wai-json-0.9.2-BZNRBMFwE4jKXoJhm8EnCY
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2018 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
abi: abd0ec7a7a22270241310f8b163fce67
exposed: True
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
import-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-wai-json-0.9.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hspec-wai-json-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hspec-wai-json-0.9.2
hs-libraries: HShspec-wai-json-0.9.2-BZNRBMFwE4jKXoJhm8EnCY
depends:
    aeson-1.4.2.0-Avxlg2iWl9mA2BcbnSAv1Y
    aeson-qq-0.8.2-29W42v1vJeIA1khEq3mn base-4.12.0.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hspec-wai-0.9.2-HJW5Qwrtq8w5vfK8VIYdJj template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
